@@ -132,12 +132,12 @@ L<Continuity>
 
 =head1 AUTHOR
 
-  Brock Wilcox <awwaiid@thelackthereof.org>
-  http://thelackthereof.org/
+  Brock Wilcox <awwaiid@thelackthereof.org> - http://thelackthereof.org/
+  Scott Walters <scott@slowass.net> - http://slowass.net/
 
 =head1 COPYRIGHT
 
-  Copyright (c) 2004-2006 Brock Wilcox <awwaiid@thelackthereof.org>. All rights
+  Copyright (c) 2004-2007 Brock Wilcox <awwaiid@thelackthereof.org>. All rights
   reserved.  This program is free software; you can redistribute it and/or
   modify it under the same terms as Perl itself.
 
